<nav class="pv3 ph3 ph4-ns" role="navigation">
  <div class="flex-l center items-center justify-between">
    <a href="{{ .Site.Home.RelPermalink }}" class="f3 dib no-underline site-nav-title">
      {{ if not .IsHome }}
        <div class="site-nav-logo-wrap" style="background-image: url('{{ "unicow.jpg" | relURL }}')"></div>
      {{ end }}
      {{ .Site.Title }}
    </a>
    <div class="flex-l items-center">
      {{ partials.Include "i18nlist.html" . }}
      {{ if .Site.Menus.main }}
        <ul class="{{ compare.Conditional (compare.Eq $.Site.Language.LanguageDirection "rtl") "pr0 ml3" "pl0 mr3" }}">
          {{ range .Site.Menus.main }}
          <li class="list f5 f4-ns fw4 dib {{ compare.Conditional (compare.Eq $.Site.Language.LanguageDirection "rtl") "pl3" "pr3" }}">
            <a class="hover-white white-90 no-underline" href="{{ .URL }}" title="{{ lang.Translate "pageTitle" . }}">
              {{ .Name }}
            </a>
          </li>
          {{ end }}
        </ul>
      {{ end }}
      {{ partials.IncludeCached "social/follow.html" . }}
    </div>
  </div>
</nav>
