{{- $title := cond .IsHome .Site.Title (printf "%s | %s" .Title .Site.Title) -}}
{{- $desc := or .Description (cond .IsPage .Summary (.Site.Params.description | default "")) -}}
{{- $image := partial "func/GetFeaturedImage.html" . -}}
{{- if not $image }}{{- with .Site.Params.og_image }}{{- $image = . | absURL }}{{- end }}{{- end -}}
<meta property="og:title" content="{{ $title }}" />
<meta property="og:description" content="{{ $desc | plainify | truncate 200 }}" />
<meta property="og:type" content="{{ if .IsPage }}article{{ else }}website{{ end }}" />
<meta property="og:url" content="{{ .Permalink }}" />
<meta property="og:site_name" content="{{ .Site.Title }}" />
{{ with $image -}}
<meta property="og:image" content="{{ . }}" />
{{ end -}}
{{ if .IsPage -}}
<meta property="article:published_time" content="{{ .Date.Format "2006-01-02T15:04:05Z07:00" }}" />
<meta property="article:modified_time" content="{{ .Lastmod.Format "2006-01-02T15:04:05Z07:00" }}" />
{{ end -}}
